Fix some spello's pointed out by Gabor Greif


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@24019 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/TwoAddressInstructionPass.cpp b/lib/CodeGen/TwoAddressInstructionPass.cpp
index 2e6d826..3aa2cc7 100644
--- a/lib/CodeGen/TwoAddressInstructionPass.cpp
+++ b/lib/CodeGen/TwoAddressInstructionPass.cpp
@@ -46,7 +46,7 @@
   Statistic<> NumTwoAddressInstrs("twoaddressinstruction",
                                   "Number of two-address instructions");
   Statistic<> NumCommuted("twoaddressinstruction",
-                          "Number of instructions commuted to coallesce");
+                          "Number of instructions commuted to coalesce");
   Statistic<> NumConvertedTo3Addr("twoaddressinstruction",
                                 "Number of instructions promoted to 3-address");
 
@@ -127,7 +127,7 @@
 
         // If this instruction is not the killing user of B, see if we can
         // rearrange the code to make it so.  Making it the killing user will
         // allow us to coallesce A and B together, eliminating the copy we are
         // about to insert.
         if (!LV.KillsRegister(mi, regB)) {
           const TargetInstrDescriptor &TID = TII.get(opcode);
@@ -127,7 +127,7 @@
         // If this instruction is not the killing user of B, see if we can
         // rearrange the code to make it so.  Making it the killing user will
-        // allow us to coallesce A and B together, eliminating the copy we are
+        // allow us to coalesce A and B together, eliminating the copy we are
         // about to insert.
         if (!LV.KillsRegister(mi, regB)) {